=========
Reference
=========

Corpus
--------------

.. autoclass:: gismo.corpus.Corpus
    :members:
.. autoclass:: gismo.corpus.CorpusList
    :members:

Embedding
--------------------

.. autoclass:: gismo.embedding.Embedding
    :members:

DIteration
------------------
.. autoclass:: gismo.diteration.DIteration
    :members:

Clustering
-----------------
.. automodule:: gismo.clustering
    :members:

Gismo
--------------
.. autoclass:: gismo.gismo.Gismo
    :members:

.. autoclass:: gismo.gismo.XGismo
    :members:


PostProcessors
-----------------
.. automodule:: gismo.post_processing
    :members:

FileSource
----------------
.. automodule:: gismo.filesource
    :members:


Sentencizer
----------------
.. automodule:: gismo.sentencizer
    :members:


Datasets
--------
.. automodule:: gismo.datasets.acm
    :members:

.. automodule:: gismo.datasets.dblp
    :members:

.. automodule:: gismo.datasets.reuters
    :members:

Common
------

.. automodule:: gismo.common
    :members:
